@@ -1,6 +1,8 @@
 /* Functions to support link list bitsets.
-   Copyright (C) 2002-2004, 2006, 2009-2010 Free Software Foundation,
-   Inc.
+
+   Copyright (C) 2002, 2003, 2004, 2006, 2009, 2010 Free Software
+   Foundation, Inc.
+
    Contributed by Michael Hayes (m.hayes@elec.canterbury.ac.nz).
 
    This program is free software: you can redistribute it and/or modify
