@@ -1,6 +1,7 @@
 /* Find and resolve or report lookahead conflicts for bison,
-   Copyright (C) 2000-2002, 2004, 2007, 2009-2010 Free Software
-   Foundation, Inc.
+
+   Copyright (C) 2000, 2001, 2002, 2004, 2007, 2009, 2010 Free
+   Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
