@@ -1,7 +1,7 @@
 /* Parse command line arguments for Bison.
 
    Copyright (C) 1984, 1986, 1989, 1992, 2000, 2001, 2002, 2003, 2004,
-   2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+   2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -70,9 +70,9 @@ static struct bison_language const valid_languages[] = {
   { "", "", "", "", false }
 };
 
-static int skeleton_prio = 2;
+int skeleton_prio = default_prio;
 const char *skeleton = NULL;
-static int language_prio = 2;
+int language_prio = default_prio;
 struct bison_language const *language = &valid_languages[0];
 const char *include = NULL;
 
@@ -265,7 +265,7 @@ Operation modes:\n\
       --print-localedir      output directory containing locale-dependent data\n\
       --print-datadir        output directory containing skeletons and XSLT\n\
   -y, --yacc                 emulate POSIX Yacc\n\
-  -W, --warnings=[CATEGORY]  report the warnings falling in CATEGORY\n\
+  -W, --warnings[=CATEGORY]  report the warnings falling in CATEGORY\n\
 \n\
 "), stdout);
 
@@ -370,9 +370,9 @@ skeleton_arg (char const *arg, int prio, location const *loc)
       char const *msg =
 	_("multiple skeleton declarations are invalid");
       if (loc)
-	complain_at (*loc, msg);
+	complain_at (*loc, "%s", msg);
       else
-	complain (msg);
+	complain ("%s", msg);
     }
 }
 
@@ -520,11 +520,11 @@ getargs (int argc, char *argv[])
 	break;
 
       case 'L':
-	language_argmatch (optarg, 0, NULL);
+	language_argmatch (optarg, command_line_prio, NULL);
 	break;
 
       case 'S':
-	skeleton_arg (AS_FILE_NAME (optarg), 0, NULL);
+	skeleton_arg (AS_FILE_NAME (optarg), command_line_prio, NULL);
 	break;
 
       case 'T':
